Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(191)

Unified Diff: base/base_paths_win.h

Issue 2079233004: Add the Windows.IsPinnedToTaskbar metric. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Constexpr TimeDelta Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/base_paths_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/base_paths_win.h
diff --git a/base/base_paths_win.h b/base/base_paths_win.h
index 761226e0addd484df2662bcc9cf86deec6c5a3d2..2db16a62719bb454223b23314f46b19976b3f4c5 100644
--- a/base/base_paths_win.h
+++ b/base/base_paths_win.h
@@ -25,23 +25,25 @@ enum {
DIR_PROGRAM_FILESX86, // See table above.
DIR_PROGRAM_FILES6432, // See table above.
- DIR_IE_INTERNET_CACHE, // Temporary Internet Files directory.
- DIR_COMMON_START_MENU, // Usually "C:\ProgramData\Microsoft\Windows\
- // Start Menu\Programs"
- DIR_START_MENU, // Usually "C:\Users\<user>\AppData\Roaming\Microsoft\
- // Windows\Start Menu\Programs"
- DIR_APP_DATA, // Application Data directory under the user profile.
- DIR_LOCAL_APP_DATA, // "Local Settings\Application Data" directory under
- // the user profile.
- DIR_COMMON_APP_DATA, // Usually "C:\ProgramData".
- DIR_APP_SHORTCUTS, // Where tiles on the start screen are stored, only
- // for Windows 8. Maps to "Local\AppData\Microsoft\
- // Windows\Application Shortcuts\".
- DIR_COMMON_DESKTOP, // Directory for the common desktop (visible
- // on all user's Desktop).
- DIR_USER_QUICK_LAUNCH, // Directory for the quick launch shortcuts.
- DIR_TASKBAR_PINS, // Directory for the shortcuts pinned to taskbar.
- DIR_WINDOWS_FONTS, // Usually C:\Windows\Fonts.
+ DIR_IE_INTERNET_CACHE, // Temporary Internet Files directory.
+ DIR_COMMON_START_MENU, // Usually "C:\ProgramData\Microsoft\Windows\
+ // Start Menu\Programs"
+ DIR_START_MENU, // Usually "C:\Users\<user>\AppData\Roaming\
+ // Microsoft\Windows\Start Menu\Programs"
+ DIR_APP_DATA, // Application Data directory under the user
+ // profile.
+ DIR_LOCAL_APP_DATA, // "Local Settings\Application Data" directory
+ // under the user profile.
+ DIR_COMMON_APP_DATA, // Usually "C:\ProgramData".
+ DIR_APP_SHORTCUTS, // Where tiles on the start screen are stored,
+ // only for Windows 8. Maps to "Local\AppData\
+ // Microsoft\Windows\Application Shortcuts\".
+ DIR_COMMON_DESKTOP, // Directory for the common desktop (visible
+ // on all user's Desktop).
+ DIR_USER_QUICK_LAUNCH, // Directory for the quick launch shortcuts.
+ DIR_TASKBAR_PINS, // Directory for the shortcuts pinned to taskbar.
+ DIR_IMPLICIT_APP_SHORTCUTS, // The implicit user pinned shortcut directory.
+ DIR_WINDOWS_FONTS, // Usually C:\Windows\Fonts.
PATH_WIN_END
};
« no previous file with comments | « no previous file | base/base_paths_win.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698